data {
  int<lower=1> h; // number of mixture components
  int<lower=1> n; // number of data points
  real y[n]; // observations
}
parameters {
  simplex[h] lambda; // mixing proportions
  real mu[h]; // locations of mixture components
  real<lower=0> sigma;
}
model {
  real ps[h];
  mu ~ normal(0, 5);
  lambda ~ dirichlet(rep_vector(2.0/h, h));

  for (i in 1:n) {
    for (j in 1:h)
      ps[j] = log(lambda[j]) + normal_lpdf(y[i] | mu[j], sigma);
    target += log_sum_exp(ps);
  }
  sigma ~ cauchy(0, 2.5);
}
generated quantities {
  real mu_ordered[h];
  mu_ordered = sort_asc(mu);
}
