data {
  int<lower=0> t_;
  real y[t_];
}
parameters {
  real arma_const;
  real phi;
  real theta;
  real<lower=0> sigma_t_eq_1;
  real<lower=0> garch_const;
  real<lower=0> arch0;
  real<lower=0> garch0;
}
model {
  real mu[t_];
  real error;
  real error2;
  real sigma[t_];
  real sigma2[t_];

  mu[1] = arma_const + phi * arma_const / (1 - phi);
  error = y[1] - mu[1];
  error2 = pow(error, 2);
  sigma2[1] = pow(sigma_t_eq_1, 2);
  sigma[1] = sigma_t_eq_1;

  for (t in 2:t_) {
    mu[t] = arma_const + phi * y[t-1] + theta * error;
    sigma2[t] = garch_const + garch0 * sigma2[t-1] + arch0 * error2;
    error = y[t] - mu[t];
    error2 = pow(error, 2);
    sigma[t] = sqrt(sigma2[t]);
  }

  y ~ normal(mu, sigma);
  sigma_t_eq_1 ~ cauchy(0, 2.5);
}
